@@ -348,11 +348,11 @@ void *sumfile(char *filename, hashid algorithm, char *password, int plen)
 	} else {
 
 		td =
-		    hmac_mhash_init(algorithm, password, plen,
+		    mhash_hmac_init(algorithm, password, plen,
 				    mhash_get_hash_pblock(algorithm));
 	}
 
-	if (td < 0) {
+	if (td == MHASH_FAILED) {
 		sprintf(msg, "Internal library error.\n");
 		err_crit(msg);
 		return NULL;
@@ -380,7 +380,7 @@ void *sumfile(char *filename, hashid algorithm, char *password, int plen)
 	if (password == NULL) {
 		return mhash_end(td);
 	} else {
-		return hmac_mhash_end(td);
+		return mhash_hmac_end(td);
 	}
 }
 
